summaryrefslogtreecommitdiff
path: root/methods
diff options
context:
space:
mode:
Diffstat (limited to 'methods')
-rw-r--r--methods/gpgv.cc8
-rw-r--r--methods/sqv.cc2
2 files changed, 5 insertions, 5 deletions
diff --git a/methods/sqv.cc b/methods/sqv.cc
index 45d001af1..ce7e36657 100644
--- a/methods/sqv.cc
+++ b/methods/sqv.cc
@@ -296,7 +296,7 @@ bool SQVMethod::URIAcquire(std::string const &Message, FetchItem *Itm)
if (_error->PendingError())
return false;
- // Run apt-key on file, extract contents and get the key ID of the signer
+ // Run sqv on file, extract contents and get the key ID of the signer
VerifyGetSigners(Path.c_str(), Itm->DestFile.c_str(), keyFiles, Signers);
if (_error->PendingError())
{
diff --git a/methods/gpgv.cc b/methods/gpgv.cc
index 8eda8d67f..1a6356dee 100644
--- a/methods/gpgv.cc
+++ b/methods/gpgv.cc
@@ -211,7 +211,7 @@ string GPGVMethod::VerifyGetSigners(const char *file, const char *outfile,
FILE *pipein = fdopen(fd[0], "r");
// Loop over the output of apt-key (which really is gnupg), and check the signatures.
std::vector<std::string> ErrSigners;
std::map<std::string, std::vector<std::string>> SubKeyMapping;
size_t buffersize = 0;
@@ -337,7 +337,7 @@ string GPGVMethod::VerifyGetSigners(const char *file, const char *outfile,
for (auto errSigner : ErrSigners)
Signers.Worthless.push_back({errSigner, ""});
// apt-key has a --keyid parameter, but this requires gpg, so we call it without it
// and instead check after the fact which keyids where used for verification
if (keyFpts.empty() == false)
{
@@ -562,7 +562,7 @@ bool GPGVMethod::URIAcquire(std::string const &Message, FetchItem *Itm)
keyFpts.emplace_back(std::move(key));
}
// Run apt-key on file, extract contents and get the key ID of the signer
string const msg = VerifyGetSignersWithLegacy(Path.c_str(), Itm->DestFile.c_str(), keyFpts, keyFiles, Signers);
if (_error->PendingError())
return false;
@@ -657,7 +657,7 @@ bool GPGVMethod::URIAcquire(std::string const &Message, FetchItem *Itm)
Dequeue();
if (DebugEnabled())
- std::clog << "apt-key succeeded\n";
+ std::clog << "gpgv succeeded\n";
return true;
}
@@ -211,7 +211,7 @@ string GPGVMethod::VerifyGetSigners(const char *file, const char *outfile,
FILE *pipein = fdopen(fd[0], "r");
- // Loop over the output of apt-key (which really is gnupg), and check the signatures.
+ // Loop over the output of gpgv, and check the signatures.
std::vector<std::string> ErrSigners;
std::map<std::string, std::vector<std::string>> SubKeyMapping;
@@ -337,7 +337,7 @@ string GPGVMethod::VerifyGetSigners(const char *file, const char *outfile,
for (auto errSigner : ErrSigners)
Signers.Worthless.push_back({errSigner, ""});
- // apt-key has a --keyid parameter, but this requires gpg, so we call it without it
+ // gpgv has no --keyid parameter, so we call it without it
// and instead check after the fact which keyids where used for verification
if (keyFpts.empty() == false)
@@ -562,7 +562,7 @@ bool GPGVMethod::URIAcquire(std::string const &Message, FetchItem *Itm)
keyFpts.emplace_back(std::move(key));
}
- // Run apt-key on file, extract contents and get the key ID of the signer
+ // Run gpgv on file, extract contents and get the key ID of the signer
string const msg = VerifyGetSignersWithLegacy(Path.c_str(), Itm->DestFile.c_str(), keyFpts, keyFiles, Signers);
if (_error->PendingError())